@@ -12,10 +12,12 @@ class ChartMixin(ABC):
 
     beginAtZero = True
     aspectRatio = True
+    stepSize = 0.5
     title = None
     legend = False
     type_chart = None
     _colors = None
+    tooltips = []
 
     @abstractmethod
     def generate_dataset(self):
@@ -50,7 +52,7 @@ class ChartMixin(ABC):
         )
 
     def _get_rgba_from_hex(self, color_hex):
-        color = color.lstrip("#")
+        color = color_hex.lstrip("#")
         rgb = [int(color[i : i + 2], 16) for i in [0, 2, 4]]
 
         return "rgba({},{},{},0.6)".format(*map(lambda x: x, rgb))
@@ -59,7 +61,6 @@ class ChartMixin(ABC):
 class BarChart(ChartMixin):
 
     type_chart = "bar"
-    tooltips = []
 
     def generate_options(self):
         options = super().generate_options()
@@ -67,7 +68,7 @@ class BarChart(ChartMixin):
             "yAxes": [
                 {
                     "display": True,
-                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": 1},
+                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": self.stepSize},
                 }
             ]
         }
@@ -104,7 +105,7 @@ class HorizontalBarChart(ChartMixin):
             "xAxes": [
                 {
                     "display": True,
-                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": 1},
+                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": self.stepSize},
                 }
             ]
         }
@@ -188,7 +189,7 @@ class LineChart(ChartMixin):
             "yAxes": [
                 {
                     "display": True,
-                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": 1},
+                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": self.stepSize},
                 }
             ]
         }
