@@ -12,9 +12,12 @@ class BaseChartView(ABC):
     legend = False
     beginAtZero = False
     aspectRatio = True
+    stepSize = 0.5
     width = 100
     height = 100
-    tooltip = None
+    
+    def get_tooltips(self):
+        return []
 
     @abstractmethod
     def generate_values(self):
@@ -52,7 +55,7 @@ class BaseChartView(ABC):
         context["chart"] = {
             "data": self._generate_data(),
             "options": self.generate_options(),
-            "tooltip": self.tooltip if self.tooltip is not None else " ",
+            "tooltip": self.get_tooltips() if len(self.get_tooltips()) > 0 else " ",
         }
         context["type"] = self.type_chart
         if self.aspectRatio is not True:
@@ -63,7 +66,7 @@ class BaseChartView(ABC):
 
 
 class BarChartView(BaseChartView):
-    label = ""
+    
     type_chart = "bar"
 
     def _generate_data(self):
@@ -76,21 +79,15 @@ class BarChartView(BaseChartView):
     def generate_options(self):
         options = super().generate_options()
         options["scales"] = {
-            "yAxes": [{"display": True, "ticks": {"beginAtZero": True}}]
+            "yAxes": [{"display": True, "ticks": {"beginAtZero": self.beginAtZero,"stepSize": self.stepSize}}]
         }
 
-        """options["tooltips"] = {
-            "callbacks": { 
-                "label": json.dumps("function(tooltipItem,data){ var dataset = data.datasets[tooltipItem.datasetIndex]; return dataset; }")
-            }
-        }"""
-
         return json.dumps(options)
 
     def _generate_dataset(self, values):
         collection = []
         dataset = {
-            "label": self.label,
+            "label": self.get_tooltips() if len(self.get_tooltips()) > 0 else "",
             "backgroundColor": [self._get_color() for entry in self.generate_labels()],
             "data": values,
         }
@@ -155,7 +152,7 @@ class LineChartView(BaseChartView):
             "yAxes": [
                 {
                     "display": True,
-                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": 1},
+                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": self.stepSize},
                 }
             ]
         }
